package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysTeacherCertificate;

/**
 * certificateService接口
 *
 * @author srs
 * @date 2024-05-30
 */
public interface ISysTeacherCertificateService extends IService<SysTeacherCertificate> {
    /**
     * 查询certificate
     *
     * @param certificateId certificate主键
     * @return certificate
     */
    public SysTeacherCertificate selectSysTeacherCertificateByCertificateId(Long certificateId);

    /**
     * 查询certificate列表
     *
     * @param sysTeacherCertificate certificate
     * @return certificate集合
     */
    List<SysTeacherCertificate> selectSysTeacherCertificateList(SysTeacherCertificate sysTeacherCertificate);

    /**
     * 新增certificate
     *
     * @param sysTeacherCertificate certificate
     * @return 结果
     */
    int insertSysTeacherCertificate(SysTeacherCertificate sysTeacherCertificate);

    /**
     * 修改certificate
     *
     * @param sysTeacherCertificate certificate
     * @return 结果
     */
    int updateSysTeacherCertificate(SysTeacherCertificate sysTeacherCertificate);

    /**
     * 批量删除certificate
     *
     * @param certificateIds 需要删除的certificate主键集合
     * @return 结果
     */
    int deleteSysTeacherCertificateByCertificateIds(Long[] certificateIds);

    /**
     * 删除certificate信息
     *
     * @param certificateId certificate主键
     * @return 结果
     */
    int deleteSysTeacherCertificateByCertificateId(Long certificateId);
}
